@@ -5,7 +5,7 @@ from pollination.honeybee_radiance.octree import CreateOctreeWithSky
 from pollination.honeybee_radiance.translate import CreateRadianceFolderView
 
 # input/output alias
-from pollination.alias.inputs.model import hbjson_model_input
+from pollination.alias.inputs.model import hbjson_model_view_input
 from pollination.alias.inputs.pit import point_in_time_view_metric_input
 from pollination.alias.inputs.radiancepar import rad_par_view_input
 from pollination.alias.inputs.bool_options import skip_overture_input
@@ -22,7 +22,7 @@ class PointInTimeViewEntryPoint(DAG):
     model = Inputs.file(
         description='A Honeybee model in HBJSON file format.',
         extensions=['json', 'hbjson', 'pkl', 'hbplk'],
-        alias=hbjson_model_input
+        alias=hbjson_model_view_input
     )
 
     sky = Inputs.str(
@@ -47,11 +47,11 @@ class PointInTimeViewEntryPoint(DAG):
     resolution = Inputs.int(
         description='An integer for the maximum dimension of each image in pixels '
         '(either width or height depending on the input view angle and type).',
-        spec={'type': 'integer', 'minimum': 1}, default=512
+        spec={'type': 'integer', 'minimum': 1}, default=800
     )
 
     view_filter = Inputs.str(
-        description='Text for a view identifer or a pattern to filter the views '
+        description='Text for a view identifier or a pattern to filter the views '
         'of the model that are simulated. For instance, first_floor_* will simulate '
         'only the views that have an identifier that starts with first_floor_. By '
         'default, all views in the model will be simulated.',
@@ -79,7 +79,7 @@ class PointInTimeViewEntryPoint(DAG):
 
     radiance_parameters = Inputs.str(
         description='The radiance parameters for ray tracing',
-        default='-ab 2 -aa 0.1 -ad 2048 -ar 64',
+        default='-ab 2 -aa 0.25 -ad 512 -ar 16',
         alias=rad_par_view_input
     )
 
